@@ -32,3 +32,6 @@ EXCHANGE_INFO_URL = DATA_URL + 'exchanges/general'
 BLOCKCHAIN_BASE_URL = DATA_URL + 'blockchain/'
 BLOCKCHAIN_AVAILABLE_COINS_URL = BLOCKCHAIN_BASE_URL + 'list'
 BLOCKCHAIN_HISTORICAL_DAILY_URL = BLOCKCHAIN_BASE_URL + 'histo/day'
+
+# News API
+NEWS_URL = DATA_V2_URL + 'news/'
